@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use Carp();
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 sub _DOES_NOT_APPLY { return -1 }
 
@@ -32,7 +32,7 @@ sub on_content_load {
     my $old = $self->{onContentLoad};
     if ( @_ > 1 ) {
         if ( defined $new ) {
-            if ( $new =~ /^(\d+|-1)$/smx ) {
+            if ( $new =~ /^(\d+(?:[.]\d+)?|-1)$/smx ) {
                 $self->{onContentLoad} = $1 + 0;
             }
             else {
@@ -56,7 +56,7 @@ sub on_load {
     my $old = $self->{onLoad};
     if ( @_ > 1 ) {
         if ( defined $new ) {
-            if ( $new =~ /^(\d+|\-1)$/smx ) {
+            if ( $new =~ /^(\d+(?:[.]\d+)?|\-1)$/smx ) {
                 $self->{onLoad} = $1 + 0;
             }
             else {
@@ -143,7 +143,7 @@ Archive::Har::Page::PageTimings - Represents detailed timing of page within the
 
 =head1 VERSION
 
-Version '0.20'
+Version '0.21'
 
 =for stopwords HAR PageTimings undef
 
